==> haskell-base-unicode-symbols-0.2.4.2-14-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-base-unicode-symbols.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 base-unicode-symbols
version:              0.2.4.2
visibility:           public
id:                   base-unicode-symbols-0.2.4.2-LxaiYZxX2IHCdJ6KOk7ePF
key:                  base-unicode-symbols-0.2.4.2-LxaiYZxX2IHCdJ6KOk7ePF
license:              BSD-3-Clause
copyright:            2009–2019 Roel van Dijk <roel@lambdacube.nl>
maintainer:           Roel van Dijk <roel@lambdacube.nl>
author:               Roel van Dijk <roel@lambdacube.nl>
stability:            provisional
homepage:             http://haskell.org/haskellwiki/Unicode-symbols
synopsis:             Unicode alternatives for common functions and operators
description:
    This package defines new symbols for a number of functions,
    operators and types in the base package.

    All symbols are documented with their actual definition and
    information regarding their Unicode code point. They should be
    completely interchangeable with their definitions.

    For further Unicode goodness you can enable the @UnicodeSyntax@
    language extension [1]. This extension enables Unicode characters
    to be used to stand for certain ASCII character sequences,
    i.e. &#x2192; instead of @->@, &#x2200; instead of @forall@ and many
    others.

    Original idea by P&#xE9;ter Divi&#xE1;nszky.

    \[1] <https://downloads.haskell.org/~ghc/latest/docs/html/users_guide/glasgow_exts.html#unicode-syntax>

abi:                  09dda79e1fdbb83a771e8d0415d07421
exposed:              True
exposed-modules:
    Control.Applicative.Unicode Control.Arrow.Unicode
    Control.Category.Unicode Control.Monad.Unicode Data.Bool.Unicode
    Data.Eq.Unicode Data.Foldable.Unicode Data.Function.Unicode
    Data.List.Unicode Data.Monoid.Unicode Data.Ord.Unicode
    Data.String.Unicode Numeric.Natural.Unicode Prelude.Unicode

import-dirs:          /usr/lib/ghc-9.2.8/site-local/base-unicode-symbols-0.2.4.2
library-dirs:         /usr/lib/ghc-9.2.8/site-local/base-unicode-symbols-0.2.4.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-base-unicode-symbols
hs-libraries:         HSbase-unicode-symbols-0.2.4.2-LxaiYZxX2IHCdJ6KOk7ePF
depends:              base-4.16.4.0
haddock-interfaces:
    /usr/share/doc/haskell-base-unicode-symbols/html/base-unicode-symbols.haddock

haddock-html:         /usr/share/doc/haskell-base-unicode-symbols/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-base-unicode-symbols-0.2.4.2-15-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-base-unicode-symbols.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 base-unicode-symbols
version:              0.2.4.2
visibility:           public
id:                   base-unicode-symbols-0.2.4.2-DGP2ohBQv5PB4jg5C9PUqH
key:                  base-unicode-symbols-0.2.4.2-DGP2ohBQv5PB4jg5C9PUqH
license:              BSD-3-Clause
copyright:            2009–2019 Roel van Dijk <roel@lambdacube.nl>
maintainer:           Roel van Dijk <roel@lambdacube.nl>
author:               Roel van Dijk <roel@lambdacube.nl>
stability:            provisional
homepage:             http://haskell.org/haskellwiki/Unicode-symbols
synopsis:             Unicode alternatives for common functions and operators
description:
    This package defines new symbols for a number of functions,
    operators and types in the base package.

    All symbols are documented with their actual definition and
    information regarding their Unicode code point. They should be
    completely interchangeable with their definitions.

    For further Unicode goodness you can enable the @UnicodeSyntax@
    language extension [1]. This extension enables Unicode characters
    to be used to stand for certain ASCII character sequences,
    i.e. &#x2192; instead of @->@, &#x2200; instead of @forall@ and many
    others.

    Original idea by P&#xE9;ter Divi&#xE1;nszky.

    \[1] <https://downloads.haskell.org/~ghc/latest/docs/html/users_guide/glasgow_exts.html#unicode-syntax>

abi:                  a15369505755f5954f776e9efb4c0451
exposed:              True
exposed-modules:
    Control.Applicative.Unicode Control.Arrow.Unicode
    Control.Category.Unicode Control.Monad.Unicode Data.Bool.Unicode
    Data.Eq.Unicode Data.Foldable.Unicode Data.Function.Unicode
    Data.List.Unicode Data.Monoid.Unicode Data.Ord.Unicode
    Data.String.Unicode Numeric.Natural.Unicode Prelude.Unicode

import-dirs:          /usr/lib/ghc-9.4.8/site-local/base-unicode-symbols-0.2.4.2
library-dirs:         /usr/lib/ghc-9.4.8/site-local/base-unicode-symbols-0.2.4.2
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/base-unicode-symbols-0.2.4.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-base-unicode-symbols
hs-libraries:         HSbase-unicode-symbols-0.2.4.2-DGP2ohBQv5PB4jg5C9PUqH
depends:              base-4.17.2.1
haddock-interfaces:
    /usr/share/doc/haskell-base-unicode-symbols/html/base-unicode-symbols.haddock

haddock-html:         /usr/share/doc/haskell-base-unicode-symbols/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
